@@ -23,6 +23,24 @@ while (!file.access(mlwin, mode = 1) == 0) {
 }
 options(MLwiN_path = mlwin)
 
+# Change contrasts if wish to avoid warning indicating that, by default,
+# specified contrasts for ordered predictors will be ignored by runMLwiN
+# (they will be fitted as "contr.treatment" regardless of this setting). To
+# enable specified contrasts, set allowcontrast to TRUE (this will be the
+# default in future package releases). NB at the end of this script, the
+# specification for contrasts is changed back.
+my_contrasts <- options("contrasts")$contrasts
+options(contrasts = c(unordered = "contr.treatment",
+                      ordered = "contr.treatment"))
+
+# As an alternative to changing contrasts, can instead use C() to specify
+# contrasts for ordered predictors in formula object, e.g.:
+
+# (mymodel <- runMLwiN(log(use4) ~ 1 + C(lc, "contr.treatment"),
+#                      D = "Unordered Multinomial",
+#                      estoptions = list(EstM = 1),
+#                      data = bang,
+#                      allowcontrast = TRUE))
 
 ## Read bang data
 data(bang, package = "R2MLwiN")
@@ -82,8 +100,10 @@ round(cov2cor(RP3.cons), 3)
 
 # Chapter learning outcomes . . . . . . . . . . . . . . . . . . . . . . .128
 
+# Addendum: changing contrasts back to pre-existing . . . . . . . . . . . NA
 
-
-
+# Following re-specification of contrast settings towards the start of this
+# script, change contrasts back to pre-existing:
+options(contrasts = my_contrasts)
 
 ############################################################################
